/**
 * Copyright (c) 2009, Opera Software ASA
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of Opera Software ASA nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY OPERA SOFTWARE ASA AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL OPERA SOFTWARE ASA AND CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
 
/**
 * @fileoverview
 * Yusef Profile Sync Plugin.
 *
 * @author David Håsäther (davidh@opera.com)
 * @version 0.1
 */
Yusef.addPlugin
(
    "profileSync",
    /**
     */
    function Yusef_plugins_profile()
    {
        var self = this;
        /**
         * @constant URL path where this plugin specific files are exposed
         */
        this.PLUGIN_PATH = 'yusef_plugins_profileSync';
        /**
         * @constant Id used to publish content on the {@link PSO} object.
         */
        var ERR = 'Yusef.plugins.profileSync';

        this.status = null;

        this.getData = function()
        {
            return {
                status: widget.preferenceForKey("yusef.plugins.profileSync.status")
            };
        }

        function parser(text, xml, connection)
        {
            var el = (xml.getElementsByTagName("status")||[])[0];
            return el ? el.textContent : "";
        }

        function sync()
        {
            var fetcher = new ResourceFetcher();
            fetcher.parser = parser;
            fetcher.addCallback(onResourceUpdated);
            if(opera.io.webserver.username)
            {
                fetcher.addUrl("http://" + opera.io.webserver.hostName + "/_root/profile");
            } else {
                fetcher.addUrl("/_root/profile");
            }

            function onResourceUpdated(url, data)
            {
                widget.setPreferenceForKey(data, "yusef.plugins.profileSync.status");
            }
        };

        sync();
    }
);
